@@ -1,3 +1,6 @@
+""" Tests Settings
+"""
+
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
@@ -8,3 +11,5 @@ INSTALLED_APPS = [
     # Local app
     "tests",
 ]
+MONGODB_INDEXING = False
+MONGODB_ASYNC_SAVE = False
